%
% Finite differece for Pendulum
% OV = old values OV(1) = x position 
%                 OV(2) = y position
%                 OV(3) = x velocity
%                 OV(4) = y velocity
%
% L  = multiplier for constraint (a vector of 1 element)
% omega, zeta = parameter for Baumgarte constraint stabilizartion
%
% m, g, r = parameter of the model, respectively mass, gravity an ray.
%
% NV = solution of the linear finite difference of the DAE with
%      assigned multiplier.
%
function NV = EvalFD( OV, L, DT, omega, zeta, m, g, r )
  t1  = OV(1);
  t2  = OV(3);
  t5  = (DT ^ 2);
  t9  = 1 / (-1 + 2 * L(1) * t5);
  t11 = OV(2);
  t12 = OV(4);
  t14 = (m * g);
  t17 = L(1) * DT;

  NV  = zeros(4,1) ;
  NV(1) = -(t1 + DT * t2) * t9;
  NV(2) = (-t11 - DT * t12 + t14 * t5) * t9;
  NV(3) = -(t2 + 2 * t17 * t1) * t9;
  NV(4) = (-t12 + t14 * DT - 2 * t17 * t11) * t9;
end